import numpy
from matplotlib import pyplot
import harkbasenode
import time


class HarkNode(harkbasenode.HarkBaseNode):
    def __init__(self):
        self.outputNames = ("OUTPUT",)
        self.outputTypes = ("prim_int",)

        self.showwave = None
        self.wavelen = 16000 * 3
        # matplotlib.use('PDF')
        pyplot.ion()
        pyplot.hold(False)

    def calculate(self):
        self.outputValues["OUTPUT"] = 0

        if self.showwave is None:
            self.showwave = numpy.array(self.WAVE)
        else:
            self.showwave = numpy.concatenate(
                (self.showwave, self.WAVE), axis=1)

        if self.count % 100 == 0:
            if self.showwave.shape[1] > self.wavelen:
                self.showwave = self.showwave[:, len(self.showwave)-self.wavelen:]

            for ch in range(self.showwave.shape[0]):
                pyplot.subplot(self.showwave.shape[0], 1, ch+1)
                pyplot.plot(self.showwave[ch, :])
                pyplot.xlim([0, self.wavelen])
                pyplot.xticks(range(0, self.wavelen, 5000),
                           range(self.count, self.count + self.wavelen, 5000))
                pyplot.ylabel("Magnitude")
                mx = max(abs(self.showwave[ch, :]))
                pyplot.ylim([-mx, mx])

            if self.count == 0:
                pyplot.xlabel("Time [frame]")
            pyplot.pause(0.01)

    def __del__(self):
        pyplot.close()

if __name__ == "__main__":
    import cProfile
    for i in range(5):
        calculate(i, numpy.zeros((3, 512)))
